@@ -470,7 +470,7 @@ class BibleMateGUI:
 
                     # --- Mobile Avatar Button (Home) ---
                     # This is a button that contains the avatar
-                    with ui.button(on_click=lambda: self.load_area_2_content(self.work_in_progress)).props('flat round dense').classes('lt-sm'):
+                    with ui.button(on_click=lambda: ui.navigate.to('/')).props('flat round dense').classes('lt-sm'):
                         with ui.avatar(size='32px'):
                             with ui.image(config.avatar if config.avatar else os.path.join(BIBLEMATEGUI_APP_DIR, 'eliranwong.jpg')) as image:
                                 with image.add_slot('error'):
@@ -478,7 +478,7 @@ class BibleMateGUI:
 
                     # --- Desktop Avatar + Title (Home) ---
                     # The button contains a row with the avatar and the label
-                    with ui.button(on_click=lambda: self.load_area_2_content(self.work_in_progress)).props('flat text-color=white').classes('gt-xs'):
+                    with ui.button(on_click=lambda: ui.navigate.to('/')).props('flat text-color=white').classes('gt-xs'):
                         with ui.row().classes('items-center no-wrap'):
                             # Use a fallback icon in case the image fails to load
                             with ui.avatar(size='32px'):
@@ -610,7 +610,7 @@ class BibleMateGUI:
 
             # Home Link
             ui.item('Home', on_click=lambda: (
-                self.load_area_2_content(self.work_in_progress),
+                ui.navigate.to('/'),
                 app.storage.user.update(left_drawer_open=False)
             )).props('clickable')
             ui.switch('Dark Mode').bind_value(app.storage.user, 'dark_mode').on_value_change(lambda: ui.run_javascript('location.reload()'))
